# Yuio

[![test](https://github.com/taminomara/yuio/actions/workflows/ci.yaml/badge.svg)](https://github.com/taminomara/yuio/actions/workflows/ci.yaml) [![coverage](https://taminomara.github.io/yuio/coverage.svg)](https://taminomara.github.io/yuio/)

Yuio is everything you'll ever need to write a good CLI, deps-free.

Forget searching for *that one progressbar library*,
figuring out how to keep loading configs DRY,
or having headaches because autocompletion was just an afterthought.
Yuio got you.

## Resources

- [Documentation](https://yuio.readthedocs.io/)
- [Issues](https://github.com/taminomara/yuio/issues)
- [Source](https://github.com/taminomara/yuio/)
- [PyPi](https://pypi.org/project/yuio/)
- [Changelog](https://github.com/taminomara/yuio/blob/main/CHANGELOG.md)

## Requirements

The only requirement is `python >= 3.10`.

## Installation

Install `yuio` with pip:

```sh
pip install yuio
```
